==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/english/original_sections/admin/content_manager.lang.inc.php <==
<?php
/**
 * content_manager.lang.inc.php 2020-4-1
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = array(
	'BADGE_STATUS_NOT_ACTIVE'            => 'not visible',
	'BADGE_STATUS_SOME_ACTIVE'           => 'partly visible',
	'CONFIRM_DELETE'                     => 'Do you really want to delete this content?',
	'CONFIRM_DELETE_HEADLINE'            => 'Delete?',
	'CONTENT_GROUP_ID'                   => 'Content group ID',
	'CONTENT_NOTE'                       => 'Content marked <font color="#ff0000">*</font> is a part of the system and cannot be deleted!',
	'CONTENT_TITLE'                      => 'Content',
	'CREATE_MATRIX'                      => 'Create matrix',
	'DELETE_CONTENT_ERROR_TEXT'          => 'Unfortunately the chosen content could not be deleted.',
	'DELETE_CONTENT_ERROR_TITLE'         => 'Content could not be deleted',
	'DESCRIPTION_CONTENT'                => 'Content page',
	'DESCRIPTION_FILE'                   => 'File/Script',
	'DESCRIPTION_LINK'                   => 'External link',
	'DESCRIPTION_PRODUCT_CONTENT_FILE'   => 'File',
	'DESCRIPTION_PRODUCT_CONTENT_LINK'   => 'External link',
	'DESCRIPTION_PRODUCT_CONTENT_TEXT'   => 'Text',
	'DOWNLOAD_FILE_LABEL'                => 'As download',
	'DOWNLOAD_FILE_TEXT'                 => 'Here you can select a file that corresponds for example to the content as a PDF file.',
    'ELEMENT_TYPE'                       => 'Element Type',
    'ELEMENT_TYPE_INFO'                  => 'Content',
	'ERROR_COMMENT'                      => 'Please enter a file description!',
	'ERROR_FILE'                         => 'Incorrect file format (.html, .htm, .xhtml, .xml, .txt, .js, .pdf only)',
	'ERROR_TITLE'                        => 'Please enter a title',
	'GM_ERROR_CONTENT_GROUP_ID_EXISTS'   => 'The language group entered already exists. Choose a free language group  e.g. "{ID}".',
	'GM_LINK'                            => 'Link',
	'GM_LINK_BLANK'                      => 'Open in new window',
	'GM_LINK_TOP'                        => 'Open in same window',
	'GM_META_DESCRIPTION'                => 'Meta Description',
	'GM_META_KEYWORDS'                   => 'Meta Keywords',
	'GM_META_TITLE'                      => 'Meta Title',
	'GM_ROBOTS_ENTRY'                    => 'Add to robots.txt (disallow)',
	'GM_SITEMAP_CHANGEFREQ'              => 'Change frequency in sitemap',
	'GM_SITEMAP_ENTRY'                   => 'link in sitemap',
	'GM_SITEMAP_PRIORITY'                => 'Priority in sitemap',
	'GM_TEXT_URL_REWRITE'                => 'URL Rewrite',
	'GM_TEXT_URL_REWRITE_CONTENT_INFO'   => 'Here you can define a link to the content, independent of the content title, content heading and the URL keywords.',
	'GM_URL_KEYWORDS'                    => 'URL Keywords',
	'GM_WARNING_CONTENT_GROUP_ID_EXISTS' => 'The language group entered already exists. Choose a free language group  e.g. "{ID}".',
	'HEADING_BOXES'                      => 'Boxes',
	'HEADING_STYLEEDIT'                  => 'StyleEdit',
	'HEADING_CONTENT'                    => 'Site content',
	'HEADING_FILE'                       => 'File/Script',
	'HEADING_FOOTER'                     => 'Footer',
	'HEADING_GROUP_CHECK'                => 'Customer Status',
	'HEADING_HEADER'                     => 'Header',
	'HEADING_HOME_PAGE'                  => 'Homepage',
	'HEADING_INFO_BOX'                   => 'Information Box',
	'HEADING_ADDITIONAL'                 => 'Additional pages',
	'HEADING_INFO_PAGES'                 => 'More about...',
	'HEADING_LINK'                       => 'External link',
	'HEADING_MAIN_CATEGORIES'            => 'Main categories',
	'HEADING_OTHERS'                     => 'Others',
	'HEADING_PRODUCTS_CONTENT'           => 'Product Content',
	'HEADING_SECONDARY_NAVIGATION'       => 'Secondary navigation',
	'HEADING_SUB_TITLE'                  => 'Tools',
	'HEADING_TITLE'                      => 'Content Manager',
	'HEADING_WITHDRAWAL'                 => 'Withdrawal',
	'INTERNAL_NAME'                      => 'Internal name',
	'LABEL_ADDRESS'                      => 'Link address',
	'LABEL_NAME'                         => 'Internal Name',
	'LABEL_OPEN_NEW_WINDOW'              => 'Open in a new window',
	'LABEL_PRODUCT_CONTENT_FILE'         => 'File',
	'LABEL_PRODUCT_CONTENT_LINK'         => 'Link',
	'LABEL_PRODUCT_CONTENT_TEXT'         => 'Text',
	'LABEL_PRODUCT_CONTENT_TYPE'         => 'Content type',
	'LABEL_SHOW_FOR_PRODUCT'             => 'Show for product',
	'LABEL_TITLE'                        => 'Title',
	'LABLE_GROUPCHECK_ADMIN'             => 'Admin',
	'LABLE_GROUPCHECK_ALL'               => 'All',
	'LABLE_GROUPCHECK_GUEST'             => 'Guest',
	'LABLE_GROUPCHECK_MERCHANT'          => 'Merchant',
	'LABLE_GROUPCHECK_NEW_CUSTOMER'      => 'New customer',
	'NEW_CONTENT_TITLE'                  => 'New content',
	'OPENGRAPH_IMAGE'                    => 'Image for social media (og:image)',
	'PAGE_TITLE_ELEMENTS'                => 'Elements',
	'PAGE_TITLE_PAGES'                   => 'Pages',
	'PAGE_TITLE_PRODUCT_CONTENTS'        => 'Product contents',
	'PAGE_TYPE'                          => 'Page type',
	'PAGE_TYPE_INFO'                     => 'Content page',
	'PAGE_TYPE_LINK'                     => 'Link',
	'PAGE_TYPE_SCRIPT'                   => 'Script file',
	'SHOW_IN'                            => 'Show in',
	'TABLE_HEADING_CONTENT_ACTION'       => 'Action',
	'TABLE_HEADING_CONTENT_BOX'          => 'Position',
	'TABLE_HEADING_CONTENT_FILE'         => 'File',
	'TABLE_HEADING_CONTENT_FILESIZE'     => 'File Size',
	'TABLE_HEADING_CONTENT_GROUP'        => 'ID',
	'TABLE_HEADING_CONTENT_HITS'         => 'Viewed',
	'TABLE_HEADING_CONTENT_ID'           => 'Link ID',
	'TABLE_HEADING_CONTENT_LINK'         => 'Link',
	'TABLE_HEADING_CONTENT_NAME'         => 'Name/Filename',
	'TABLE_HEADING_CONTENT_SORT'         => 'Sort Order',
	'TABLE_HEADING_CONTENT_STATUS'       => 'Visible',
	'TABLE_HEADING_CONTENT_TITLE'        => 'Title',
	'TABLE_HEADING_LANGUAGE'             => 'Language',
	'TABLE_HEADING_PRODUCTS'             => 'Product',
	'TABLE_HEADING_PRODUCTS_CONTENT_ID'  => 'ID',
	'TABLE_HEADING_PRODUCTS_ID'          => 'ID',
	'TEXT_CHOOSE_FILE'                   => 'Choose File',
	'TEXT_CHOOSE_FILE_DESC'              => 'You also can choose an existing file from the list.',
	'TEXT_CHOOSE_FILE_SERVER'            => '(If you have already uploaded your files via FTP to <i>(media/content)</i>, you can select the file here.',
	'TEXT_CONTENT'                       => 'Content',
	'TEXT_CONTENT_DESCRIPTION'           => 'You can use this content manager to add any file type to a product, i.e. technical data sheets, product details, videos, etc. These elements will be displayed on the product details page.<br /><br />',
	'TEXT_CURRENT_FILE'                  => 'Current File:',
	'TEXT_DELETE'                        => 'Delete',
	'TEXT_EDIT'                          => 'Edit',
	'TEXT_EXTERNAL_LINK_INFO'            => 'is a external link which can not be displayed as preview.',
	'TEXT_FILE_DESC'                     => 'Description:',
	'TEXT_FILE_DESCRIPTION'              => '<b>Info:</b><br />You can also upload a <b>.html</b> or <b>.htm</b> file and display it as store content.<br /> If you select or upload a file, the text in the box will be ignored.<br /><br />',
	'TEXT_FILE_FLAG'                     => 'Position',
	'TEXT_FILENAME'                      => 'Use File:',
	'TEXT_GROUP'                         => 'ID',
	'TEXT_GROUP_DESC'                    => 'You can use this ID to link similar subjects from different languages.',
	'TEXT_HEADING'                       => 'Heading',
	'TEXT_LANGUAGE'                      => 'Language',
	'TEXT_LINK'                          => 'Link',
	'TEXT_NO'                            => 'No',
	'TEXT_NO_CONTENT'                    => 'No entries available',
	'TEXT_NO_FILE'                       => 'Delete Selection',
	'TEXT_PARENT'                        => 'Main Document:',
	'TEXT_PARENT_DESCRIPTION'            => 'Assign to this document',
	'TEXT_PREVIEW'                       => 'Preview',
	'TEXT_PRODUCT'                       => 'Product',
	'TEXT_SELECT'                        => '-Select-',
	'TEXT_SELECT_NONE'                   => 'no teaser slider',
	'TEXT_SORT_ORDER'                    => 'Sort',
	'TEXT_SORTING'                       => 'Sorting',
	'TEXT_SORTING_FAILED'                => 'New sorting could not be saved.',
	'TEXT_STATUS'                        => 'Visible',
	'TEXT_STATUS_DESCRIPTION'            => 'If checked, a link or an extra box will be displayed',
	'TEXT_TITLE'                         => 'Name',
	'TEXT_TITLE_FILE'                    => 'Title/Filename',
	'TEXT_UPLOAD_FILE'                   => 'Upload File',
	'TEXT_UPLOAD_FILE_LOCAL'             => '(from local system)',
	'TEXT_YES'                           => 'Yes',
	'TITLE_ALWAYS'                       => 'always',
	'TITLE_CONTENT_SLIDER'               => ' Content teaser slider',
	'TITLE_DAILY'                        => 'daily',
	'TITLE_HOURLY'                       => 'hourly',
	'TITLE_MONTHLY'                      => 'monthly',
	'TITLE_NEVER'                        => 'never',
	'TITLE_WEEKLY'                       => 'weekly',
	'TITLE_YEARLY'                       => 'annually',
	'TUTORIAL_INFO'                      => 'Elements that are created in this section are not immediately visible in the shop and must be integrated in the corresponding template first. A tutorial for the integration can be found',
	'TUTORIAL_INFO_LINK_TEXT'            => 'here.',
	'USED_SPACE'                         => 'Disk space used:',
	'WITHDRAWAL_FORM_FILE_LABEL'         => 'Model withdrawal form',
	'WITHDRAWAL_FORM_FILE_TEXT'          => 'If you do not want to use the standard model withdrawal form, you can select an alternative document here.',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/english/original_sections/admin/content_manager.lang.inc.php <==
<?php
/**
 * content_manager.lang.inc.php 2020-06-09
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = array(
	'BADGE_STATUS_NOT_ACTIVE'            => 'not visible',
	'BADGE_STATUS_SOME_ACTIVE'           => 'partly visible',
	'CONFIRM_DELETE'                     => 'Do you really want to delete this content?',
	'CONFIRM_DELETE_HEADLINE'            => 'Delete?',
	'CONTENT_GROUP_ID'                   => 'Content group ID',
	'CONTENT_NOTE'                       => 'Content marked <font color="#ff0000">*</font> is a part of the system and cannot be deleted!',
	'CONTENT_TITLE'                      => 'Content',
	'CREATE_MATRIX'                      => 'Create matrix',
	'DELETE_CONTENT_ERROR_TEXT'          => 'Unfortunately the chosen content could not be deleted.',
	'DELETE_CONTENT_ERROR_TITLE'         => 'Content could not be deleted',
	'DESCRIPTION_CONTENT'                => 'Content page',
	'DESCRIPTION_FILE'                   => 'File/Script',
	'DESCRIPTION_LINK'                   => 'External link',
	'DESCRIPTION_PRODUCT_CONTENT_FILE'   => 'File',
	'DESCRIPTION_PRODUCT_CONTENT_LINK'   => 'External link',
	'DESCRIPTION_PRODUCT_CONTENT_TEXT'   => 'Text',
	'DOWNLOAD_FILE_LABEL'                => 'As download',
	'DOWNLOAD_FILE_TEXT'                 => 'Here you can select a file that corresponds for example to the content as a PDF file.',
    'ELEMENT_TYPE'                       => 'Element Type',
    'ELEMENT_TYPE_INFO'                  => 'Content',
	'ERROR_COMMENT'                      => 'Please enter a file description!',
	'ERROR_FILE'                         => 'Incorrect file format (.html, .htm, .xhtml, .xml, .txt, .js, .pdf only)',
	'ERROR_TITLE'                        => 'Please enter a title',
	'GM_ERROR_CONTENT_GROUP_ID_EXISTS'   => 'The language group entered already exists. Choose a free language group  e.g. "{ID}".',
	'GM_LINK'                            => 'Link',
	'GM_LINK_BLANK'                      => 'Open in new window',
	'GM_LINK_TOP'                        => 'Open in same window',
	'GM_META_DESCRIPTION'                => 'Meta Description',
	'GM_META_KEYWORDS'                   => 'Meta Keywords',
	'GM_META_TITLE'                      => 'Meta Title',
	'GM_ROBOTS_ENTRY'                    => 'Disable SEO indexing (noindex header)',
	'GM_SITEMAP_CHANGEFREQ'              => 'Change frequency in sitemap',
	'GM_SITEMAP_ENTRY'                   => 'link in sitemap',
	'GM_SITEMAP_PRIORITY'                => 'Priority in sitemap',
	'GM_TEXT_URL_REWRITE'                => 'URL Rewrite',
	'GM_TEXT_URL_REWRITE_CONTENT_INFO'   => 'Here you can define a link to the content, independent of the content title, content heading and the URL keywords.',
	'GM_URL_KEYWORDS'                    => 'URL Keywords',
	'GM_WARNING_CONTENT_GROUP_ID_EXISTS' => 'The language group entered already exists. Choose a free language group  e.g. "{ID}".',
	'HEADING_BOXES'                      => 'Boxes',
	'HEADING_STYLEEDIT'                  => 'StyleEdit',
	'HEADING_CONTENT'                    => 'Site content',
	'HEADING_FILE'                       => 'File/Script',
	'HEADING_FOOTER'                     => 'Footer',
	'HEADING_GROUP_CHECK'                => 'Customer Status',
	'HEADING_HEADER'                     => 'Header',
	'HEADING_HOME_PAGE'                  => 'Homepage',
	'HEADING_INFO_BOX'                   => 'Information Box',
	'HEADING_ADDITIONAL'                 => 'Additional pages',
	'HEADING_INFO_PAGES'                 => 'More about...',
	'HEADING_LINK'                       => 'External link',
	'HEADING_MAIN_CATEGORIES'            => 'Main categories',
	'HEADING_OTHERS'                     => 'Others',
	'HEADING_PRODUCTS_CONTENT'           => 'Product Content',
	'HEADING_SECONDARY_NAVIGATION'       => 'Secondary navigation',
	'HEADING_SUB_TITLE'                  => 'Tools',
	'HEADING_TITLE'                      => 'Content Manager',
	'HEADING_WITHDRAWAL'                 => 'Withdrawal',
	'INTERNAL_NAME'                      => 'Internal name',
	'LABEL_ADDRESS'                      => 'Link address',
	'LABEL_NAME'                         => 'Internal Name',
	'LABEL_OPEN_NEW_WINDOW'              => 'Open in a new window',
	'LABEL_PRODUCT_CONTENT_FILE'         => 'File',
	'LABEL_PRODUCT_CONTENT_LINK'         => 'Link',
	'LABEL_PRODUCT_CONTENT_TEXT'         => 'Text',
	'LABEL_PRODUCT_CONTENT_TYPE'         => 'Content type',
	'LABEL_SHOW_FOR_PRODUCT'             => 'Show for product',
	'LABEL_TITLE'                        => 'Title',
	'LABLE_GROUPCHECK_ADMIN'             => 'Admin',
	'LABLE_GROUPCHECK_ALL'               => 'All',
	'LABLE_GROUPCHECK_GUEST'             => 'Guest',
	'LABLE_GROUPCHECK_MERCHANT'          => 'Merchant',
	'LABLE_GROUPCHECK_NEW_CUSTOMER'      => 'New customer',
	'NEW_CONTENT_TITLE'                  => 'New content',
	'OPENGRAPH_IMAGE'                    => 'Image for social media (og:image)',
	'PAGE_TITLE_ELEMENTS'                => 'Elements',
	'PAGE_TITLE_PAGES'                   => 'Pages',
	'PAGE_TITLE_PRODUCT_CONTENTS'        => 'Product contents',
	'PAGE_TYPE'                          => 'Page type',
	'PAGE_TYPE_INFO'                     => 'Content page',
	'PAGE_TYPE_LINK'                     => 'Link',
	'PAGE_TYPE_SCRIPT'                   => 'Script file',
	'SHOW_IN'                            => 'Show in',
	'TABLE_HEADING_CONTENT_ACTION'       => 'Action',
	'TABLE_HEADING_CONTENT_BOX'          => 'Position',
	'TABLE_HEADING_CONTENT_FILE'         => 'File',
	'TABLE_HEADING_CONTENT_FILESIZE'     => 'File Size',
	'TABLE_HEADING_CONTENT_GROUP'        => 'ID',
	'TABLE_HEADING_CONTENT_HITS'         => 'Viewed',
	'TABLE_HEADING_CONTENT_ID'           => 'Link ID',
	'TABLE_HEADING_CONTENT_LINK'         => 'Link',
	'TABLE_HEADING_CONTENT_NAME'         => 'Name/Filename',
	'TABLE_HEADING_CONTENT_SORT'         => 'Sort Order',
	'TABLE_HEADING_CONTENT_STATUS'       => 'Visible',
	'TABLE_HEADING_CONTENT_TITLE'        => 'Title',
	'TABLE_HEADING_LANGUAGE'             => 'Language',
	'TABLE_HEADING_PRODUCTS'             => 'Product',
	'TABLE_HEADING_PRODUCTS_CONTENT_ID'  => 'ID',
	'TABLE_HEADING_PRODUCTS_ID'          => 'ID',
	'TEXT_CHOOSE_FILE'                   => 'Choose File',
	'TEXT_CHOOSE_FILE_DESC'              => 'You also can choose an existing file from the list.',
	'TEXT_CHOOSE_FILE_SERVER'            => '(If you have already uploaded your files via FTP to <i>(media/content)</i>, you can select the file here.',
	'TEXT_CONTENT'                       => 'Content',
	'TEXT_CONTENT_DESCRIPTION'           => 'You can use this content manager to add any file type to a product, i.e. technical data sheets, product details, videos, etc. These elements will be displayed on the product details page.<br /><br />',
	'TEXT_CURRENT_FILE'                  => 'Current File:',
	'TEXT_DELETE'                        => 'Delete',
	'TEXT_EDIT'                          => 'Edit',
	'TEXT_EXTERNAL_LINK_INFO'            => 'is a external link which can not be displayed as preview.',
	'TEXT_FILE_DESC'                     => 'Description:',
	'TEXT_FILE_DESCRIPTION'              => '<b>Info:</b><br />You can also upload a <b>.html</b> or <b>.htm</b> file and display it as store content.<br /> If you select or upload a file, the text in the box will be ignored.<br /><br />',
	'TEXT_FILE_FLAG'                     => 'Position',
	'TEXT_FILENAME'                      => 'Use File:',
	'TEXT_GROUP'                         => 'ID',
	'TEXT_GROUP_DESC'                    => 'You can use this ID to link similar subjects from different languages.',
	'TEXT_HEADING'                       => 'Heading',
	'TEXT_LANGUAGE'                      => 'Language',
	'TEXT_LINK'                          => 'Link',
	'TEXT_NO'                            => 'No',
	'TEXT_NO_CONTENT'                    => 'No entries available',
	'TEXT_NO_FILE'                       => 'Delete Selection',
	'TEXT_PARENT'                        => 'Main Document:',
	'TEXT_PARENT_DESCRIPTION'            => 'Assign to this document',
	'TEXT_PREVIEW'                       => 'Preview',
	'TEXT_PRODUCT'                       => 'Product',
	'TEXT_SELECT'                        => '-Select-',
	'TEXT_SELECT_NONE'                   => 'no teaser slider',
	'TEXT_SORT_ORDER'                    => 'Sort',
	'TEXT_SORTING'                       => 'Sorting',
	'TEXT_SORTING_FAILED'                => 'New sorting could not be saved.',
	'TEXT_STATUS'                        => 'Visible',
	'TEXT_STATUS_DESCRIPTION'            => 'If checked, a link or an extra box will be displayed',
	'TEXT_TITLE'                         => 'Name',
	'TEXT_TITLE_FILE'                    => 'Title/Filename',
	'TEXT_UPLOAD_FILE'                   => 'Upload File',
	'TEXT_UPLOAD_FILE_LOCAL'             => '(from local system)',
	'TEXT_YES'                           => 'Yes',
	'TITLE_ALWAYS'                       => 'always',
	'TITLE_CONTENT_SLIDER'               => ' Content teaser slider',
	'TITLE_DAILY'                        => 'daily',
	'TITLE_HOURLY'                       => 'hourly',
	'TITLE_MONTHLY'                      => 'monthly',
	'TITLE_NEVER'                        => 'never',
	'TITLE_WEEKLY'                       => 'weekly',
	'TITLE_YEARLY'                       => 'annually',
	'TUTORIAL_INFO'                      => 'Elements that are created in this section are not immediately visible in the shop and must be integrated in the corresponding template first. A tutorial for the integration can be found',
	'TUTORIAL_INFO_LINK_TEXT'            => 'here.',
	'USED_SPACE'                         => 'Disk space used:',
	'WITHDRAWAL_FORM_FILE_LABEL'         => 'Model withdrawal form',
	'WITHDRAWAL_FORM_FILE_TEXT'          => 'If you do not want to use the standard model withdrawal form, you can select an alternative document here.',
    'BUTTON_OPEN_PAGE_IN_SE4'            => 'Open page in StyleEdit4',
    'COPY_LINK'                          => 'Copy Link',
    'COPIED'                             => 'Copied',
);
